# Generated by roxygen2: do not edit by hand

S3method(adjust_lambda,bhm)
S3method(adjust_lambda,default)
S3method(adjust_lambda,exnex)
S3method(geom_borrow,fujikawa)
S3method(geom_posterior,fujikawa)
S3method(geom_prior,fujikawa)
S3method(get_details,app)
S3method(get_details,bhm)
S3method(get_details,binomial)
S3method(get_details,cpp)
S3method(get_details,cppglobal)
S3method(get_details,cpplim)
S3method(get_details,exnex)
S3method(get_details,fujikawa)
S3method(get_details,jsdglobal)
S3method(get_details,mml)
S3method(get_details,mmlglobal)
S3method(get_evaluation,app)
S3method(get_evaluation,bhm)
S3method(get_evaluation,cpp)
S3method(get_evaluation,cpplim)
S3method(get_evaluation,exnex)
S3method(get_evaluation,fujikawa)
S3method(get_results,app)
S3method(get_results,bhm)
S3method(get_results,cpp)
S3method(get_results,cppglobal)
S3method(get_results,cpplim)
S3method(get_results,exnex)
S3method(get_results,fujikawa)
S3method(get_results,jsdglobal)
S3method(get_results,mml)
S3method(get_results,mmlglobal)
export(adjust_lambda)
export(ecd)
export(geom_borrow)
export(geom_posterior)
export(geom_prior)
export(get_data)
export(get_details)
export(get_evaluation)
export(get_results)
export(get_scenarios)
export(opt_design)
export(setup_app)
export(setup_bhm)
export(setup_binomial)
export(setup_cpp)
export(setup_cppglobal)
export(setup_cpplim)
export(setup_exnex)
export(setup_fujikawa)
export(setup_jsdglobal)
export(setup_mml)
export(setup_mmlglobal)
export(toer)
importFrom(doFuture,"%dofuture%")
